@@ -1,7 +1,7 @@
 extern crate forkjoin;
 extern crate rand;
 
-use forkjoin::{FJData,TaskResult,ForkPool,AlgoStyle,ReduceStyle,Algorithm};
+use forkjoin::{TaskResult,ForkPool,AlgoStyle,ReduceStyle,Algorithm};
 use rand::Rng;
 
 #[test]
@@ -39,7 +39,7 @@ fn quicksort_par(d: &mut[usize], threads: usize) {
 }
 
 #[cfg(test)]
-fn quicksort_task(d: &mut [usize], _: FJData) -> TaskResult<&mut [usize], ()> {
+fn quicksort_task(d: &mut [usize], _: usize) -> TaskResult<&mut [usize], ()> {
     let len = d.len();
     if len <= 1000 {
         quicksort_seq(d);
